@@ -2,7 +2,7 @@
   SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
   SPDX-FileContributor: Tobias Koenig <tokoe@kdab.com>
 
-  SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -106,20 +106,19 @@ Q_SIGNALS:
                                 const QString &attachment);
 
 private:
-    QModelIndex createGroup(const QString &groupName);
-    void createSnippet(const QModelIndex &groupIndex,
-                       const QString &snippetName,
-                       const QString &snippetText,
-                       const QString &snippetKeySequence,
-                       const QString &snippetKeyword,
-                       const QString &snippetSubject,
-                       const QString &to,
-                       const QString &cc,
-                       const QString &bcc,
-                       const QString &attachment);
+    MAILCOMMON_NO_EXPORT QModelIndex createGroup(const QString &groupName);
+    MAILCOMMON_NO_EXPORT void createSnippet(const QModelIndex &groupIndex,
+                                            const QString &snippetName,
+                                            const QString &snippetText,
+                                            const QString &snippetKeySequence,
+                                            const QString &snippetKeyword,
+                                            const QString &snippetSubject,
+                                            const QString &to,
+                                            const QString &cc,
+                                            const QString &bcc,
+                                            const QString &attachment);
     SnippetItem *mRootItem = nullptr;
     QMap<QString, QString> mSavedVariables;
 };
 }
 Q_DECLARE_TYPEINFO(MailCommon::SnippetsInfo, Q_MOVABLE_TYPE);
-
