@@ -1,6 +1,6 @@
 /*
   SPDX-FileCopyrightText: 2003 Andreas Gungl <a.gungl@gmx.de>
-  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -12,7 +12,6 @@
 
 #include <KIdentityManagement/Identity>
 #include <KIdentityManagement/IdentityCombo>
-#include <KIdentityManagement/IdentityManager>
 
 #include <MailTransport/TransportComboBox>
 
@@ -205,7 +204,7 @@ void RedirectDialog::accept()
 {
     const QString editTo = d->mEditTo->resend();
     if (editTo.isEmpty()) {
-        KMessageBox::sorry(this, i18n("You cannot redirect the message without an address."), i18n("Empty Redirection Address"));
+        KMessageBox::error(this, i18n("You cannot redirect the message without an address."), i18n("Empty Redirection Address"));
     } else {
         done(QDialog::Accepted);
     }
